pub struct CreateWakeGroupRequest {
pub options: WakeGroupOptions,
pub wake_watcher: EventPair,
}Fields
options: WakeGroupOptionswake_watcher: EventPairUsed by the client to signal its current power state.
WAITER_AWAKE_SIGNAL or WAITER_ASLEEP_SIGNAL, but never both,
should be asserted continuously to ensure the netstack stays
up-to-date on the current state of the client. The netstack closes
the wake group if both are asserted simultaneously or if the
eventpair is closed.
Note that this corresponds to the behavior of
[fuchsia.starnix.runner/Manager.RegisterWakeWatcher].